@@ -29,6 +29,9 @@ FAILEDOPERATION_SLOWDOWN = 'FailedOperation.SlowDown'
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
+# 参数错误。
+INVALIDPARAMETER = 'InvalidParameter'
+
 # Json 解析失败。
 INVALIDPARAMETER_JSONPARSEERROR = 'InvalidParameter.JsonParseError'
 
