@@ -26,6 +26,9 @@ FAILEDOPERATION = 'FailedOperation'
 # 部分失败（有一部分操作失败）。
 FAILEDOPERATION_PARTIALFAILURE = 'FailedOperation.PartialFailure'
 
+# 操作失败，后台依赖平台错误。
+FAILEDOPERATION_PLATFORMERROR = 'FailedOperation.PlatformError'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
@@ -50,6 +53,9 @@ INVALIDPARAMETER_ACTION = 'InvalidParameter.Action'
 # 环境ID非法。
 INVALIDPARAMETER_ENVID = 'InvalidParameter.EnvId'
 
+# 路径已存在。
+INVALIDPARAMETER_PATHEXIST = 'InvalidParameter.PathExist'
+
 # 对应资源不存在。
 INVALIDPARAMETER_RESOURCENOTEXISTS = 'InvalidParameter.ResourceNotExists'
 
@@ -113,6 +119,9 @@ RESOURCEUNAVAILABLE_CDNFREEZED = 'ResourceUnavailable.CDNFreezed'
 # 当前发票余额不足，无法退费。
 RESOURCEUNAVAILABLE_INVOICEAMOUNTLACK = 'ResourceUnavailable.InvoiceAmountLack'
 
+# 云项目oAuth授权失效（即RefreshToken过期）。
+RESOURCEUNAVAILABLE_REFRESHTOKENEXPIRED = 'ResourceUnavailable.RefreshTokenExpired'
+
 # 资源过期。
 RESOURCEUNAVAILABLE_RESOURCEOVERDUE = 'ResourceUnavailable.ResourceOverdue'
 
